#!/usr/bin/env gnuplot

set style line 1 linecolor rgbcolor "#FF0000" linewidth 1.6 pointsize 0.7
set style line 2 linecolor rgbcolor "#00FF00" linewidth 1.6 pointsize 0.7
set style line 3 linecolor rgbcolor "#0000FF" linewidth 1.6 pointsize 0.7
set style line 4 linecolor rgbcolor "#FF00FF" linewidth 1.6 pointsize 0.7
set style line 5 linecolor rgbcolor "#00FFFF" linewidth 1.6 pointsize 0.7
set style line 6 linecolor rgbcolor "#808080" linewidth 1.6 pointsize 0.7
set style line 7 linecolor rgbcolor "#D0D020" linewidth 1.6 pointsize 0.7
set style line 8 linecolor rgbcolor "#FF4C00" linewidth 1.6 pointsize 0.7
set style line 9 linecolor rgbcolor "#000000" linewidth 1.6 pointsize 0.7
set style increment user

set terminal pdf size 5, 3.5
set output 'ratio-raspi-over-i7.pdf'

### 1st Plot

set key top left
set xrange [6.5:23.5]
set xlabel "Items [log2(n)]"
set ylabel "Microseconds / Insert"
set format x "%.0f"

set title "Speed Test Multimap - Normalized Time - Insert/Find/Erase (125-8192000 Items)"
set label 1 "Raspberry Pi Model B" at screen 0.04, screen 0.04

# COLUMNPLOT SELECT LOG(2,col0) AS x, col1 / col0 * 1e6 AS "std::multiset", col2 / col0 * 1e6 AS "__gnu_cxx::hash_multiset", col3 / col0 * 1e6 AS "std::tr1::unordered_set", col4 / col0 * 1e6 AS "stx::btree_multiset<4>", col18 / col0 * 1e6 AS "stx::btree_multiset<32>", col34 / col0 * 1e6 AS "stx::btree_multiset<64>", col66 / col0 * 1e6 AS "stx::btree_multiset<128>", col102 / col0 * 1e6 AS "stx::btree_multiset<200>" FROM raspi ORDER BY x
plot \
    'speedtest-ratio-data.txt' index 0 using 1:2 title 'std::multiset' with linespoints, \
    'speedtest-ratio-data.txt' index 0 using 1:3 title '__gnu_cxx::hash_multiset' with linespoints, \
    'speedtest-ratio-data.txt' index 0 using 1:4 title 'std::tr1::unordered_set' with linespoints, \
    'speedtest-ratio-data.txt' index 0 using 1:5 title 'stx::btree_multiset<4>' with linespoints, \
    'speedtest-ratio-data.txt' index 0 using 1:6 title 'stx::btree_multiset<32>' with linespoints, \
    'speedtest-ratio-data.txt' index 0 using 1:7 title 'stx::btree_multiset<64>' with linespoints, \
    'speedtest-ratio-data.txt' index 0 using 1:8 title 'stx::btree_multiset<128>' with linespoints, \
    'speedtest-ratio-data.txt' index 0 using 1:9 title 'stx::btree_multiset<200>' with linespoints

set title "Speed Test Multimap - Normalized Time - Insert/Find/Erase (125-65536000 Items)"
set label 1 "Intel i7 920" at screen 0.04, screen 0.04

# COLUMNPLOT SELECT LOG(2,col0) AS x, col1 / col0 * 1e6 AS "std::multiset", col2 / col0 * 1e6 AS "__gnu_cxx::hash_multiset", col3 / col0 * 1e6 AS "std::tr1::unordered_set", col4 / col0 * 1e6 AS "stx::btree_multiset<4>", col18 / col0 * 1e6 AS "stx::btree_multiset<32>", col34 / col0 * 1e6 AS "stx::btree_multiset<64>", col66 / col0 * 1e6 AS "stx::btree_multiset<128>", col102 / col0 * 1e6 AS "stx::btree_multiset<200>" FROM i7 ORDER BY x
plot \
    'speedtest-ratio-data.txt' index 1 using 1:2 title 'std::multiset' with linespoints, \
    'speedtest-ratio-data.txt' index 1 using 1:3 title '__gnu_cxx::hash_multiset' with linespoints, \
    'speedtest-ratio-data.txt' index 1 using 1:4 title 'std::tr1::unordered_set' with linespoints, \
    'speedtest-ratio-data.txt' index 1 using 1:5 title 'stx::btree_multiset<4>' with linespoints, \
    'speedtest-ratio-data.txt' index 1 using 1:6 title 'stx::btree_multiset<32>' with linespoints, \
    'speedtest-ratio-data.txt' index 1 using 1:7 title 'stx::btree_multiset<64>' with linespoints, \
    'speedtest-ratio-data.txt' index 1 using 1:8 title 'stx::btree_multiset<128>' with linespoints, \
    'speedtest-ratio-data.txt' index 1 using 1:9 title 'stx::btree_multiset<200>' with linespoints


set title "Speed Test Multimap - Ratio - Insert/Find/Erase (125-8192000 Items)"
set ylabel "Ratio Speed (Raspberry Pi / Intel i7)"
unset label 1

# COLUMNPLOT SELECT LOG(2,i7.col0) AS x, raspi.col1 / i7.col1 AS "std::multiset", raspi.col2 / i7.col2 AS "__gnu_cxx::hash_multiset", raspi.col3 / i7.col3 AS "std::tr1::unordered_set", raspi.col4 / i7.col4 AS "stx::btree_multiset<4>", raspi.col18 / i7.col18 AS "stx::btree_multiset<32>", raspi.col34 / i7.col34 AS "stx::btree_multiset<64>", raspi.col66 / i7.col66 AS "stx::btree_multiset<128>", raspi.col102 / i7.col102 AS "stx::btree_multiset<200>" FROM i7 LEFT JOIN raspi ON raspi.col0 = i7.col0 ORDER BY x
plot \
    'speedtest-ratio-data.txt' index 2 using 1:2 title 'std::multiset' with linespoints, \
    'speedtest-ratio-data.txt' index 2 using 1:3 title '__gnu_cxx::hash_multiset' with linespoints, \
    'speedtest-ratio-data.txt' index 2 using 1:4 title 'std::tr1::unordered_set' with linespoints, \
    'speedtest-ratio-data.txt' index 2 using 1:5 title 'stx::btree_multiset<4>' with linespoints, \
    'speedtest-ratio-data.txt' index 2 using 1:6 title 'stx::btree_multiset<32>' with linespoints, \
    'speedtest-ratio-data.txt' index 2 using 1:7 title 'stx::btree_multiset<64>' with linespoints, \
    'speedtest-ratio-data.txt' index 2 using 1:8 title 'stx::btree_multiset<128>' with linespoints, \
    'speedtest-ratio-data.txt' index 2 using 1:9 title 'stx::btree_multiset<200>' with linespoints
